package jalview.util.imagemaker;

import static org.testng.Assert.assertEquals;

import org.testng.annotations.Test;

import jalview.bin.Cache;

public class BitmapImageSizeTest
{
  @Test(groups = { "Functional" })
  public void testCacheSettingsRecovery()
  {
    Cache.setPropsAreReadOnly(true);
    Cache.loadProperties("test/jalview/bin/testProps.jvprops");

    Cache.removeProperty(BitmapImageSizing.BITMAP_HEIGHT);
    Cache.removeProperty(BitmapImageSizing.BITMAP_SCALE);
    Cache.removeProperty(BitmapImageSizing.BITMAP_WIDTH);

    BitmapImageSizing def = BitmapImageSizing.defaultBitmapImageSizing();
    BitmapImageSizing zero = BitmapImageSizing.nullBitmapImageSizing();

    assertEquals(def.height(), zero.height());
    assertEquals(def.width(), zero.width());
    assertEquals(def.scale(), zero.scale());

    Cache.setProperty(BitmapImageSizing.BITMAP_HEIGHT, "120");
    Cache.setProperty(BitmapImageSizing.BITMAP_SCALE, "24");
    Cache.setProperty(BitmapImageSizing.BITMAP_WIDTH, "360");

    // default now updates dynamically
    // def = BitmapImageSizing.defaultBitmapImageSizing();

    assertEquals(def.height(), 120);
    assertEquals(def.width(), 360);
    assertEquals(def.scale(), 24f);

    Cache.removeProperty(BitmapImageSizing.BITMAP_WIDTH);

    // def = BitmapImageSizing.defaultBitmapImageSizing();
    assertEquals(def.height(), 120);
    assertEquals(def.width(), zero.width());
    assertEquals(def.scale(), 24f);
  }
}
